#!/bin/bash
######################################################################
#By Tummy a.k.a Vincent C. Passaro				     #
#Vincent[.]Passaro[@]gmail[.]com	         		     #
#www.vincentpassaro.com						     #
######################################################################
#_____________________________________________________________________
#|  Version |   Change Information  |      Author        |    Date    |
#|__________|_______________________|____________________|____________|
#|    1.0   |   Initial Script      | Vincent C. Passaro | 20-oct-2011|
#|	    |   Creation	    |                    |            |
#|__________|_______________________|____________________|____________|
#
#
#  - Updated by Shannon Mitchell(shannon.mitchell@fusiontechnology-llc.com)
# on 05-jan-2012 to include an ACL check before running setfacl.
								     

#######################DISA INFORMATION###############################
#Group ID (Vulid): V-22313
#Group Title: GEN001190
#Rule ID: SV-26359r1_rule
#Severity: CAT II
#Rule Version (STIG-ID): GEN001190
#Rule Title: All network services daemon files must not have extended ACLs.
#
#Vulnerability Discussion: Restricting permission on daemons will protect 
#them from unauthorized modification and possible system compromise.
#
#Responsibility: System Administrator
#IAControls: ECLP-1
#
#Check Content: 
#Check that network services daemon files have no extended ACLs.
# ls -la /usr/sbin
#If the permissions include a '+', the file has an extended ACL, this 
#is a finding.
#
#Fix Text: Remove the extended ACL from the file.
# setfacl --remove-all /usr/sbin/*   
#######################DISA INFORMATION###############################

#Global Variables#
PDI=GEN001190

#Start-Lockdown
for CURFILE in `find /usr/sbin/ ! -type l`
do
  if [ -e "$CURFILE" ]
  then
    ACLOUT=`getfacl --skip-base $CURFILE 2>/dev/null`;
    if [ "$ACLOUT" != "" ]
      then
      setfacl --remove-all $CURFILE
    fi

  fi
done

