#!/bin/bash
#####################Fotis Networks LLC###############################
#By Tummy a.k.a Vincent C. Passaro				     #
#Fotis Networks LLC						     #
#Vincent[.]Passaro[@]fotisnetworks[.]com			     #
#www.fotisnetworks.com						     #
######################Fotis Networks LLC##############################

#_____________________________________________________________________
#|  Version |   Change Information  |      Author        |    Date    |
#|__________|_______________________|____________________|____________|
#|    1.0   |   Initial Script      | Vincent C. Passaro | 20-oct-2011|
#|	    |   Creation	    |                    |            |
#|__________|_______________________|____________________|____________|
#
#
#  - Updated by Shannon Mitchell(shannon.mitchell@fusiontechnology-llc.com)
# on 09-jan-2012 to move from manual to prod and create a check for it.
								     

#######################DISA INFORMATION###############################
#Group ID (Vulid): V-796
#Group Title: System Files and Directories Group Ownership
#Rule ID: SV-796r7_rule
#Severity: CAT II
#Rule Version (STIG-ID): GEN001240
#Rule Title: System files, programs, and directories must be group-owned 
#by a system group.
#
#Vulnerability Discussion: Restricting permissions will protect the files 
#from unauthorized modification.
#
#Responsibility: System Administrator
#IAControls: ECLP-1
#
#Check Content: 
#Check the group-ownership of system files, programs, and directories.
#
#Procedure:
# ls -lLa /etc /bin /usr/bin /usr/lbin /usr/usb /sbin /usr/sbin
#
#If any system file, program, or directory is not owned by a system 
#group, this is a finding.
#
#Fix Text: Change the group-owner of system files to a system group.
#
#Procedure:
# chgrp root /path/to/system/file
#
#(System groups other than root may be used.)   
#######################DISA INFORMATION###############################

#Global Variables#
PDI=GEN001240

#Start-Lockdown
function is_system_group {

  CURGROUP=$1

  # Check that the group belongs to a system group(GID<500)
  for SYSGROUP in `awk -F ':' '{if($3 < 500) print $1}' /etc/group`
  do
    if [ "$SYSGROUP" = "$CURGROUP" ]
    then
      return 0
    fi
  done

  return 1
}

#Start-Lockdown

# Lets go through all of the files and if they are not owned by a group
# with a gid < 500,  make the group-owner root.
for CHKDIR in /etc /bin /usr/bin /usr/lbin /usr/usb /sbin /usr/sbin
do

  if [ -d "$CHKDIR" ]
  then
    for FILENAME in `find $CHKDIR ! -type l`
    do

      if [ -e "$FILENAME" ]
      then
        CURGROUP=`stat -c %G $FILENAME`;
        is_system_group $CURGROUP
        if [ $? -ne 0 ]
        then
          chgrp root $FILENAME
        fi
      fi

    done  # End "for FILENAME ..." loop

  fi  # End "if [ -d $CHKDIR..." conditional

done  # End "for CHKDIR ..." for loop
