#!/bin/bash
######################################################################
#By Tummy a.k.a Vincent C. Passaro		                     #
#Vincent[.]Passaro[@]gmail[.]com				     #
#www.vincentpassaro.com						     #
######################################################################
#_____________________________________________________________________
#|  Version |   Change Information  |      Author        |    Date    |
#|__________|_______________________|____________________|____________|
#|    1.0   |   Initial Script      | Vincent C. Passaro | 20-oct-2011|
#|	    |   Creation	    |                    |            |
#|__________|_______________________|____________________|____________|
#
#
#  - Updated by Shannon Mitchell(shannon.mitchell@fusiontechnology-llc.com)
# on 05-Feb-2012 to check permissions before running chmod and to allow for 
# "less permissive" permissions.


#######################DISA INFORMATION###############################
#Group ID (Vulid): V-832
#Group Title: aliases permissions
#Rule ID: SV-832r6_rule
#Severity: CAT II
#Rule Version (STIG-ID): GEN004380
#Rule Title: The sendmail alias files must have mode 0644 or less 
#permissive.
#
#Vulnerability Discussion: Excessive permissions on the alias files 
#may permit unauthorized modification. If an alias file is modified 
#by an unauthorized user, they may modify the file to run malicious 
#code or redirect e-mail.
#
#Responsibility: System Administrator
#IAControls: ECLP-1
#
#Check Content: 
#Check the mode of the alias files.
#
#Procedure:
# ls -lL /etc/aliases /etc/aliases.db
#If an alias file has a mode more permissive than 0644, this is a 
#finding.
#
#Fix Text: Change the mode of the alias files as needed to function. 
#No higher than 0644.
#
#Procedure:
# chmod 0644 /etc/aliases /etc/aliases.db   
#######################DISA INFORMATION###############################

#Global Variables#
PDI=GEN004380

#Start-Lockdown

if [ -a "/etc/aliases" ]
  then

    # Pull the actual permissions
    FILEPERMS=`stat -L --format='%04a' /etc/aliases`

    # Break the actual file octal permissions up per entity
    FILESPECIAL=${FILEPERMS:0:1}
    FILEOWNER=${FILEPERMS:1:1}
    FILEGROUP=${FILEPERMS:2:1}
    FILEOTHER=${FILEPERMS:3:1}

    # Run check by 'and'ing the unwanted mask(7133)
    if [ $(($FILESPECIAL&7)) != "0" ] || [ $(($FILEOWNER&1)) != "0" ] || [ $(($FILEGROUP&3)) != "0" ] || [ $(($FILEOTHER&3)) != "0" ]
      then
        chmod u-xs,g-wxs,o-wxt /etc/aliases
    fi
fi

if [ -a "/etc/aliases.db" ]
  then

    # Pull the actual permissions
    FILEPERMS=`stat -L --format='%04a' /etc/aliases.db`

    # Break the actual file octal permissions up per entity
    FILESPECIAL=${FILEPERMS:0:1}
    FILEOWNER=${FILEPERMS:1:1}
    FILEGROUP=${FILEPERMS:2:1}
    FILEOTHER=${FILEPERMS:3:1}

    # Run check by 'and'ing the unwanted mask(7133)
    if [ $(($FILESPECIAL&7)) != "0" ] || [ $(($FILEOWNER&1)) != "0" ] || [ $(($FILEGROUP&3)) != "0" ] || [ $(($FILEOTHER&3)) != "0" ]
      then
        chmod u-xs,g-wxs,o-wxt /etc/aliases.db
    fi
fi
