#!/bin/bash
######################################################################
#By Tummy a.k.a Vincent C. Passaro		                     #
#Vincent[.]Passaro[@]gmail[.]com				     #
#www.vincentpassaro.com						     #
######################################################################
#_____________________________________________________________________
#|  Version |   Change Information  |      Author        |    Date    |
#|__________|_______________________|____________________|____________|
#|    1.0   |   Initial Script      | Vincent C. Passaro | 20-oct-2011|
#|	    |   Creation	    |                    |            |
#|__________|_______________________|____________________|____________|
# 
#
#  - Updated by Shannon Mitchell(shannon.mitchell@fusiontechnology-llc.com)
# on 12-Feb-2012 to check ownership before running chown.


#######################DISA INFORMATION###############################
#Group ID (Vulid): V-928
#Group Title: Export Configuration File Ownership
#Rule ID: SV-28445r1_rule
#Severity: CAT II
#Rule Version (STIG-ID): GEN005740
#Rule Title: The NFS export configuration file must be owned by root.
#
#Vulnerability Discussion: Failure to give ownership of the NFS export configuration file to root provides the designated owner and possible unauthorized users with the potential to change system configuration which could weaken the system's security posture.
#
#Responsibility: System Administrator
#IAControls: ECLP-1
#
#Check Content: 
#Check the owner of the exports file.
#
#Example:
# ls -lL /etc/exports
#
#If the export configuration file is not owned by root, this is a finding.
#
#Fix Text: Change the owner of the exports file to root.
#
#Example:
# chown root /etc/exports   
#######################DISA INFORMATION###############################

#Global Variables#
PDI=GEN005740

#Start-Lockdown

if [ -a "/etc/exports" ]
then
  CUROWN=`stat -c %U /etc/exports`;
  if [ "$CUROWN" != "root" ]
    then
      chown root /etc/exports
  fi
fi

