#!/bin/bash
######################################################################
#By Tummy a.k.a Vincent C. Passaro		                     #
#Vincent[.]Passaro[@]gmail[.]com				     #
#www.vincentpassaro.com						     #
######################################################################
#_____________________________________________________________________
#|  Version |   Change Information  |      Author        |    Date    |
#|__________|_______________________|____________________|____________|
#|    1.0   |   Initial Script      | Vincent C. Passaro | 20-oct-2011|
#|	    |   Creation	    |                    |            |
#|__________|_______________________|____________________|____________|
#
#
#  - Updated by Shannon Mitchell(shannon.mitchell@fusiontechnology-llc.com)
# on 13-Feb-2012 to check permissions before running chmod and to allow for 
# "less permissive" permissions.


#######################DISA INFORMATION###############################
#Group ID (Vulid): V-1028
#Group Title: smb.conf permissions
#Rule ID: SV-1028r5_rule
#Severity: CAT II
#Rule Version (STIG-ID): GEN006140
#Rule Title: The /etc/samba/smb.conf file must have mode 0644 or less permissive.
#
#Vulnerability Discussion: If the smb.conf file has excessive permissions, the file may be maliciously modified and the Samba configuration could be compromised.
#
#Responsibility: System Administrator
#IAControls: ECLP-1
#
#Check Content: 
#Check the mode of the smb.conf file.
#
#Procedure:
# ls -lL /etc/samba/smb.conf
#
#If the smb.conf has a mode more permissive than 0644, this is a finding.
#
#Fix Text: Change the mode of the smb.conf file to 0644 or less permissive.
#
#Procedure:
# chmod 0644 smb.conf.   
#######################DISA INFORMATION###############################

#Global Variables#
PDI=GEN006140

#Start-Lockdown

if [ -a "/etc/samba/smb.conf" ]
  then

    # Pull the actual permissions
    FILEPERMS=`stat -L --format='%04a' /etc/samba/smb.conf`

    # Break the actual file octal permissions up per entity
    FILESPECIAL=${FILEPERMS:0:1}
    FILEOWNER=${FILEPERMS:1:1}
    FILEGROUP=${FILEPERMS:2:1}
    FILEOTHER=${FILEPERMS:3:1}

    # Run check by 'and'ing the unwanted mask(7133)
    if [ $(($FILESPECIAL&7)) != "0" ] || [ $(($FILEOWNER&1)) != "0" ] || [ $(($FILEGROUP&3)) != "0" ] || [ $(($FILEOTHER&3)) != "0" ]
      then
        chmod u-xs,g-wxs,o-wxt /etc/samba/smb.conf
    fi
fi

